==> jc-1.4.0.tar.gz: java/beans/Beans.h <==
// public class java.beans.Beans

// class file dependencies
// @dep_class d1abe10fb3effd java_beans_Beans
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_Beans_H_
#define _JC_java_beans_Beans_H_

// Forward structure declarations
struct _jc_java_beans_AppletInitializer$object;
struct _jc_java_beans_beancontext_BeanContext$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_beans_Beans$sub_refs	_jc_java_beans_Beans$sub_refs;
typedef struct _jc_java_beans_Beans$sub_nonrefs	_jc_java_beans_Beans$sub_nonrefs;
typedef struct _jc_java_beans_Beans$refs	_jc_java_beans_Beans$refs;
typedef struct _jc_java_beans_Beans$nonrefs	_jc_java_beans_Beans$nonrefs;
typedef struct _jc_java_beans_Beans$object	_jc_java_beans_Beans$object;

typedef struct _jc_java_beans_Beans$fields_struct	_jc_java_beans_Beans$fields_struct;
typedef const struct _jc_java_beans_Beans$vmethods	_jc_java_beans_Beans$vmethods;
typedef const struct _jc_java_beans_Beans$vtable	_jc_java_beans_Beans$vtable;
typedef const struct _jc_java_beans_Beans$vtype	_jc_java_beans_Beans$vtype;

// Class fields structure
struct _jc_java_beans_Beans$fields_struct {
	jboolean	designTime;
	jboolean	guiAvailable;
};
extern _jc_java_beans_Beans$fields_struct _jc_java_beans_Beans$class_fields;

// Constructors
extern void _jc_java_beans_Beans$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_beans_Beans$object *);

// Static methods
extern void _jc_java_beans_Beans$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Object$object *_jc_java_beans_Beans$method$getInstanceOf$aee39981e4977c6d(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *);
extern struct _jc_java_lang_Object$object *_jc_java_beans_Beans$method$instantiate$70299616226ef4bc(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_Object$object *_jc_java_beans_Beans$method$instantiate$e7c29ae3375871f2(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_java_beans_Beans$method$instantiate$dd74b68ce115057e(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_object *);
extern jboolean _jc_java_beans_Beans$method$isDesignTime$44646a7edef38cdd(_jc_env *);
extern jboolean _jc_java_beans_Beans$method$isGuiAvailable$5693c953d6a210b3(_jc_env *);
extern jboolean _jc_java_beans_Beans$method$isInstanceOf$eadb48d2fb9267ce(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *);
extern void _jc_java_beans_Beans$method$setDesignTime$3722f00d3a3712f2(_jc_env *, jboolean);
extern void _jc_java_beans_Beans$method$setGuiAvailable$a780fb855eb9a752(_jc_env *, jboolean);

// Virtual methods structure
struct _jc_java_beans_Beans$vmethods {
};

// Vtable
struct _jc_java_beans_Beans$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_Beans$vmethods	java_beans_Beans;
};

// Vtype
struct _jc_java_beans_Beans$vtype {
	_jc_type			type;
	_jc_java_beans_Beans$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_Beans$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_beans_Beans$refs {
    _jc_java_beans_Beans$sub_refs	java_beans_Beans;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_Beans$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_Beans$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_Beans$sub_nonrefs	java_beans_Beans;
};

// Object instance structure
struct _jc_java_beans_Beans$object {
	_jc_java_beans_Beans$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_Beans$vtype	*vtype;
	_jc_java_beans_Beans$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_Beans$vtype _jc_java_beans_Beans$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_Beans, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_Beans$class_object;

#endif	/* _JC_java_beans_Beans_H_ */

==> jc-1.4.6.tar.gz: java/beans/Beans.h <==
// public class java.beans.Beans

// class file dependencies
// @dep_class d1abe10fb3effd java_beans_Beans
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_Beans_H_
#define _JC_java_beans_Beans_H_

// Forward structure declarations
struct _jc_java_beans_AppletInitializer$object;
struct _jc_java_beans_beancontext_BeanContext$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_beans_Beans$sub_refs	_jc_java_beans_Beans$sub_refs;
typedef struct _jc_java_beans_Beans$sub_nonrefs	_jc_java_beans_Beans$sub_nonrefs;
typedef struct _jc_java_beans_Beans$refs	_jc_java_beans_Beans$refs;
typedef struct _jc_java_beans_Beans$nonrefs	_jc_java_beans_Beans$nonrefs;
typedef struct _jc_java_beans_Beans$object	_jc_java_beans_Beans$object;

typedef struct _jc_java_beans_Beans$fields_struct	_jc_java_beans_Beans$fields_struct;
typedef const struct _jc_java_beans_Beans$vmethods	_jc_java_beans_Beans$vmethods;
typedef const struct _jc_java_beans_Beans$vtable	_jc_java_beans_Beans$vtable;
typedef const struct _jc_java_beans_Beans$vtype	_jc_java_beans_Beans$vtype;

// Class fields structure
struct _jc_java_beans_Beans$fields_struct {
	jboolean	designTime;
	jboolean	guiAvailable;
};
extern _jc_java_beans_Beans$fields_struct _jc_java_beans_Beans$class_fields;

// Constructors
extern void _jc_java_beans_Beans$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_beans_Beans$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_beans_Beans$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_beans_Beans$method$getInstanceOf$aee39981e4977c6d(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_beans_Beans$method$instantiate$70299616226ef4bc(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_beans_Beans$method$instantiate$e7c29ae3375871f2(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_beans_Beans$method$instantiate$dd74b68ce115057e(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_beans_Beans$method$isDesignTime$44646a7edef38cdd(_jc_env *) _JC_JCNI_ATTR;
extern jboolean _jc_java_beans_Beans$method$isGuiAvailable$5693c953d6a210b3(_jc_env *) _JC_JCNI_ATTR;
extern jboolean _jc_java_beans_Beans$method$isInstanceOf$eadb48d2fb9267ce(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern void _jc_java_beans_Beans$method$setDesignTime$3722f00d3a3712f2(_jc_env *, jboolean) _JC_JCNI_ATTR;
extern void _jc_java_beans_Beans$method$setGuiAvailable$a780fb855eb9a752(_jc_env *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_beans_Beans$vmethods {
};

// Vtable
struct _jc_java_beans_Beans$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_Beans$vmethods	java_beans_Beans;
};

// Vtype
struct _jc_java_beans_Beans$vtype {
	_jc_type			type;
	_jc_java_beans_Beans$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_Beans$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_beans_Beans$refs {
    _jc_java_beans_Beans$sub_refs	java_beans_Beans;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_Beans$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_Beans$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_Beans$sub_nonrefs	java_beans_Beans;
};

// Object instance structure
struct _jc_java_beans_Beans$object {
	_jc_java_beans_Beans$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_Beans$vtype	*vtype;
	_jc_java_beans_Beans$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_Beans$vtype _jc_java_beans_Beans$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_Beans, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_Beans$class_object;

#endif	/* _JC_java_beans_Beans_H_ */
